@@ -22,7 +22,7 @@ my $listener = IO::Async::Listener->new(
 
       $stream->configure(
          on_read => sub {
-            my ( $self, $buffref, $closed ) = @_;
+            my ( $self, $buffref, $eof ) = @_;
 
             if( $$buffref =~ s/^(.*\n)// ) {
                # eat a line from the stream input
