@@ -12,7 +12,7 @@ use warnings;
 # It is provided simply to keep CPAN happy:
 #   cpan -i IO::Async
 
-our $VERSION = '0.36';
+our $VERSION = '0.37';
 
 =head1 NAME
 
@@ -35,7 +35,7 @@ C<IO::Async> - Asynchronous event-driven programming
 
        $stream->configure(
           on_read => sub {
-             my ( $self, $buffref, $closed ) = @_;
+             my ( $self, $buffref, $eof ) = @_;
 
              return 0 unless( $buffref =~ s/^(.*\n)// );
 
