@@ -8,7 +8,7 @@ package IO::Async::Connector;
 use strict;
 use warnings;
 
-our $VERSION = '0.36';
+our $VERSION = '0.37';
 
 use POSIX qw( EINPROGRESS );
 use Socket qw( SOL_SOCKET SO_ERROR );
@@ -226,7 +226,7 @@ is returned by the C<getaddrinfo> named resolver.
 
 Shortcut for passing a single address to connect to; it may be passed directly
 with this key, instead of in another array on its own. This should be in a
-format recognised by L<IO::Async::Loop>'s C<unpack_addrinfo> method. See also
+format recognised by L<IO::Async::Loop>'s C<extract_addrinfo> method. See also
 the C<EXAMPLES> section.
 
 =item local_addrs => ARRAY
@@ -447,10 +447,10 @@ sub connect
 
          foreach my $local ( @localaddrs ) {
             my ( $l_family, $l_socktype, $l_protocol, $l_addr ) = 
-               $loop->unpack_addrinfo( $local, 'local_addr' );
+               $loop->extract_addrinfo( $local, 'local_addr' );
             foreach my $peer ( @peeraddrs ) {
                my ( $p_family, $p_socktype, $p_protocol, $p_addr ) = 
-                  $loop->unpack_addrinfo( $peer );
+                  $loop->extract_addrinfo( $peer );
 
                next if $l_family   and $p_family   and $l_family   != $p_family;
                next if $l_socktype and $p_socktype and $l_socktype != $p_socktype;
@@ -481,36 +481,29 @@ __END__
 =head2 Passing Plain Socket Addresses
 
 The C<addr> or C<addrs> parameters should contain a definition of a plain
-socket address in a form that the L<IO::Async::Loop> C<unpack_addrinfo> method
-can use.
+socket address in a form that the L<IO::Async::Loop> C<extract_addrinfo>
+method can use.
 
 This example shows how to use the C<Socket> functions to construct one for TCP
 port 8001 on address 10.0.0.1:
 
- use Socket qw( pack_sockaddr_in inet_aton );
-
- ...
-
  $loop->connect(
     addr => {
        family   => "inet",
        socktype => "stream",
-       addr     => pack_sockaddr_in( 8001, inet_aton( "10.0.0.1" ) ),
+       port     => 8001,
+       ip       => "10.0.0.1",
     },
     ...
  );
 
 This example shows another way to connect to a UNIX socket at F<echo.sock>.
 
- use Socket qw( pack_sockaddr_un );
-
- ...
-
  $loop->connect(
     addr => {
        family   => "unix",
        socktype => "stream",
-       addr     => pack_sockaddr_un( "echo.sock" ),
+       path     => "echo.sock",
     },
     ...
  );
